icd2omop
Arguments
- codes
vector of source codes with or without wildcards
- source_wildcard
wildcard indicator in source codes. for example if code is R47.x, put "x"
- dbms_wildcard
wildcard indicator for dbms LIKE function.
- translate_from
source vocabulary, e.g., ICD9CM or ICD10CM. Make sure to enter the same way it is included in the concept table
- collect
whether to execute the query. defaults to TRUE
- overwrite
whether to overwrite the temp table created in the course of the query (#temp). defaults to TRUE
- con
the connection object to the database. defaults to option "con.default.value"
- cdm_schema
the schema containing the CDM. defaults to option "cdm_schema.default.value"