Insert a table to your user schema in chunks because speed and bugs
Source:R/insertTable_chunks.R
insertTable_chunk.RdInsert a table to your user schema in chunks because speed and bugs
Arguments
- data
data you want to write to your user schema
- table_name
the name of the table that you want to write to the database
- n
the number of chunks to split. defaults to 100. Aim for < 200 rows per chunk right now.
- overwrite
do you want to overwrite an existing table of the same name?
- con
connection. defaults to the set option if done.
- ...
additional arguments to be passed along to DatabaseConnector::insertTable
- user_schema
your user schema. defaults to the set option if done