Helper function to connect to the ohdsilab OMOP database. You will need to supply your redshift username and password (which you received in an email when you first set up your workspace). The location of the CDM schema is set by default.
The function will also set default values for your user schema, the cdm schema, and the connection object, which are used by other functions in the ohdsilab package. These can be found by running getOption("con.default.value"), getOption("schema.default.value"), and getOption("write_schema.default.value").